summaryrefslogtreecommitdiff
path: root/png.c
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2001-03-30 06:42:28 -0600
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2009-04-06 16:06:02 -0500
commit13cfbac075f9f91522421171dced2b6d2d9b523f (patch)
treec57ac08b1124cc5492874c68ef43362d114cb025 /png.c
parente164447858aed9a18a8622c734f9dce6b77c1be1 (diff)
downloadlibpng-13cfbac075f9f91522421171dced2b6d2d9b523f.tar.gz
Imported from libpng-1.0.10.tarv1.0.10
Diffstat (limited to 'png.c')
-rw-r--r--png.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/png.c b/png.c
index cfc8d656b..5dd0ff62a 100644
--- a/png.c
+++ b/png.c
@@ -1,7 +1,7 @@
/* png.c - location for general purpose libpng functions
*
* libpng version 1.0.10rc1 - March 23, 2001
* Copyright (c) 1998-2001 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -13,14 +13,14 @@
#include "png.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef version_1_0_10rc1 Your_png_h_is_not_version_1_0_10rc1;
+typedef version_1_0_10 Your_png_h_is_not_version_1_0_10;
/* Version information for C files. This had better match the version
* string defined in png.h. */
#ifdef PNG_USE_GLOBAL_ARRAYS
/* png_libpng_ver was changed to a function in version 1.0.5c */
-const char png_libpng_ver[18] = "1.0.10rc1";
+const char png_libpng_ver[18] = "1.0.10";
/* png_sig was changed to a function in version 1.0.5c */
/* Place to hold the signature string for a PNG file. */
@@ -626,7 +626,7 @@ png_charp PNGAPI
png_get_copyright(png_structp png_ptr)
{
if (png_ptr != NULL || png_ptr == NULL) /* silence compiler warning */
- return ((png_charp) "\n libpng version 1.0.10rc1 - March 23, 2001\n\
+ return ((png_charp) "\n libpng version 1.0.10 - March 30, 2001\n\
Copyright (c) 1998-2001 Glenn Randers-Pehrson\n\
Copyright (c) 1996, 1997 Andreas Dilger\n\
Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.\n");
@@ -644,8 +644,8 @@ png_get_libpng_ver(png_structp png_ptr)
{
/* Version of *.c files used when building libpng */
if(png_ptr != NULL) /* silence compiler warning about unused png_ptr */
- return((png_charp) "1.0.10rc1");
- return((png_charp) "1.0.10rc1");
+ return((png_charp) "1.0.10");
+ return((png_charp) "1.0.10");
}
png_charp PNGAPI
@@ -1,7 +1,7 @@
/* png.c - location for general purpose libpng functions
*
- * libpng version 1.0.10rc1 - March 23, 2001
+ * libpng version 1.0.10 - March 30, 2001
* Copyright (c) 1998-2001 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)